==> puma_pay-3.0.5.tar.gz: lib/helpers/appStore.dart <==
import 'dart:io';

import 'package:in_app_purchase_storekit/store_kit_wrappers.dart';
import 'package:puma_pay/entities/appStoreReceipt/appStoreReceipt.dart';
import 'package:puma_pay/entities/appStoreReceiptValidationResult/appStoreReceiptValidationResult.dart';

class AppStoreReceiptData {
  String receiptData;
  String password;
  bool excludeOldTransactions;

  AppStoreReceiptData(
      this.receiptData, this.password, this.excludeOldTransactions);

  AppStoreReceiptData.fromJson(Map<String, dynamic> json)
      : receiptData = json['receipt-data'],
        password = json['password'],
        excludeOldTransactions = json['excludeOldTransactions'];

  Map<String, dynamic> toJson() => {
        'receipt-data': receiptData,
        'password': password,
        'exclude-old-transactions': excludeOldTransactions,
      };
}

bool checkReceiptValidity(AppStoreReceiptValidationResult receiptValidation) {
  int status = receiptValidation.status;

  if (status != 0) {
    return false;
  }

  List<AppStoreReceipt> receipts = receiptValidation.latestReceiptInfo.toList();

  if (receipts.length == 0) {
    return false;
  }

  AppStoreReceipt latestReceipt = receipts.first;

  int millis = int.parse(latestReceipt.expiresDateMS);

  DateTime date = new DateTime.fromMillisecondsSinceEpoch(millis);

  if (date.isBefore(DateTime.now())) {
    return false;
  }

  return true;
}

Future<void> clearTransactionsIos() async {
  if (Platform.isIOS) {
    final transactions = await SKPaymentQueueWrapper().transactions();
    transactions.forEach((transaction) async {
      await SKPaymentQueueWrapper().finishTransaction(transaction);
    });
  }
}

==> puma_pay-3.0.10.tar.gz: lib/helpers/appStore.dart <==
import 'dart:io';

import 'package:in_app_purchase_storekit/store_kit_wrappers.dart';
import 'package:puma_pay/entities/appStoreReceipt/appStoreReceipt.dart';
import 'package:puma_pay/entities/appStoreReceiptValidationResult/appStoreReceiptValidationResult.dart';

class AppStoreReceiptData {
  String receiptData;
  String password;
  bool excludeOldTransactions;

  AppStoreReceiptData(
      this.receiptData, this.password, this.excludeOldTransactions);

  AppStoreReceiptData.fromJson(Map<String, dynamic> json)
      : receiptData = json['receipt-data'],
        password = json['password'],
        excludeOldTransactions = json['excludeOldTransactions'];

  Map<String, dynamic> toJson() => {
        'receipt-data': receiptData,
        'password': password,
        'exclude-old-transactions': excludeOldTransactions,
      };
}

bool checkReceiptValidity(AppStoreReceiptValidationResult receiptValidation) {
  int status = receiptValidation.status;

  if (status != 0) {
    return false;
  }

  List<AppStoreReceipt> receipts = receiptValidation.latestReceiptInfo.toList();

  if (receipts.length == 0) {
    return false;
  }

  AppStoreReceipt latestReceipt = receipts.last;

  int millis = int.parse(latestReceipt.expiresDateMS);

  DateTime date = new DateTime.fromMillisecondsSinceEpoch(millis);

  if (date.isBefore(DateTime.now())) {
    return false;
  }

  return true;
}

Future<void> clearTransactionsIos() async {
  if (Platform.isIOS) {
    final transactions = await SKPaymentQueueWrapper().transactions();
    transactions.forEach((transaction) async {
      await SKPaymentQueueWrapper().finishTransaction(transaction);
    });
  }
}
